==> iam-0.9.1-sources.jar: software/amazon/awscdk/services/iam/IIdentityResource.java <==
package software.amazon.awscdk.services.iam;

/**
 * @deprecated Use IPrincipal
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:14:44.764Z")
public interface IIdentityResource extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.iam.IPrincipal {

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.iam.IIdentityResource {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The IAM principal of this identity (i.e. AWS principal, service principal, etc).
         */
        @Override
        public software.amazon.awscdk.PolicyPrincipal getPrincipal() {
            return this.jsiiGet("principal", software.amazon.awscdk.PolicyPrincipal.class);
        }

        /**
         * Adds an IAM statement to the default inline policy associated with this
         * principal. If a policy doesn't exist, it is created.
         */
        @Override
        public void addToPolicy(final software.amazon.awscdk.PolicyStatement statement) {
            this.jsiiCall("addToPolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(statement, "statement is required")).toArray());
        }

        /**
         * Attaches an inline policy to this principal.
         * This is the same as calling `policy.addToXxx(principal)`.
         * @param policy The policy resource to attach to this principal.
         */
        @Override
        public void attachInlinePolicy(final software.amazon.awscdk.services.iam.Policy policy) {
            this.jsiiCall("attachInlinePolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(policy, "policy is required")).toArray());
        }

        /**
         * Attaches a managed policy to this principal.
         * @param arn The ARN of the managed policy
         */
        @Override
        public void attachManagedPolicy(final software.amazon.awscdk.Arn arn) {
            this.jsiiCall("attachManagedPolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(arn, "arn is required")).toArray());
        }
    }
}

==> iam-0.9.2-sources.jar: software/amazon/awscdk/services/iam/IIdentityResource.java <==
package software.amazon.awscdk.services.iam;

/**
 * @deprecated Use IPrincipal
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-20T13:01:38.738Z")
public interface IIdentityResource extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.iam.IPrincipal {

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.iam.IIdentityResource {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The IAM principal of this identity (i.e. AWS principal, service principal, etc).
         */
        @Override
        public software.amazon.awscdk.PolicyPrincipal getPrincipal() {
            return this.jsiiGet("principal", software.amazon.awscdk.PolicyPrincipal.class);
        }

        /**
         * Adds an IAM statement to the default inline policy associated with this
         * principal. If a policy doesn't exist, it is created.
         */
        @Override
        public void addToPolicy(final software.amazon.awscdk.PolicyStatement statement) {
            this.jsiiCall("addToPolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(statement, "statement is required")).toArray());
        }

        /**
         * Attaches an inline policy to this principal.
         * This is the same as calling `policy.addToXxx(principal)`.
         * @param policy The policy resource to attach to this principal.
         */
        @Override
        public void attachInlinePolicy(final software.amazon.awscdk.services.iam.Policy policy) {
            this.jsiiCall("attachInlinePolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(policy, "policy is required")).toArray());
        }

        /**
         * Attaches a managed policy to this principal.
         * @param arn The ARN of the managed policy
         */
        @Override
        public void attachManagedPolicy(final java.lang.String arn) {
            this.jsiiCall("attachManagedPolicy", Void.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(arn, "arn is required")).toArray());
        }
    }
}
